#ifndef NSTD_GUI_H_INCLUDED
#define NSTD_GUI_H_INCLUDED
#include "gui/def.h"
#include "gui/display.h"
#include "gui/window.h"
#include "nstd.h"
#endif
